summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorbehdad <behdad>2001-04-07 18:54:47 +0000
committerbehdad <behdad>2001-04-07 18:54:47 +0000
commit4154a1940608c55d95a6bae0523893d9e88dd213 (patch)
tree99afc676a953a8d45dcdb23eedd7af2be049df54
parent76913dfa8089aa05ce36e99448ab8a9ec75b84f3 (diff)
Small changes
-rw-r--r--TODO3
-rw-r--r--fribidi_tables.i10
-rwxr-xr-xunidata/CreateGetType.pl9
3 files changed, 13 insertions, 9 deletions
diff --git a/TODO b/TODO
index 7f6a701..09523ac 100644
--- a/TODO
+++ b/TODO
@@ -64,11 +64,8 @@ General issues:
mini_glib use < received from Dan K... >
-* test executables with mini_glib
* build execs in Makefile_mini_glib
* create a shared-object library
*** add the mini_glib option to configure, so that whenever no glib is arround,
mini_glib is used.
-
-* use smarter malloc/free scheme, even with mini_glib
diff --git a/fribidi_tables.i b/fribidi_tables.i
index f3f7028..9dc932e 100644
--- a/fribidi_tables.i
+++ b/fribidi_tables.i
@@ -1,7 +1,8 @@
/*========================================================================
-// This file was automatically created from PropList.txt, version 3.0.1,
-// and BidiMirroring.txt, version 1, by the perl script CreateGetType.pl.
-//----------------------------------------------------------------------*/
+ * This file was automatically created from PropList.txt, version 3.0.1,
+ * and BidiMirroring.txt, version 1, by the perl script CreateGetType.pl.
+ *----------------------------------------------------------------------*/
+/* *INDENT-OFF* */
#include "fribidi.h"
@@ -1099,3 +1100,6 @@ struct {
};
gint nFriBidiMirroredChars = 140;
+
+
+/* *INDENT-ON* */
diff --git a/unidata/CreateGetType.pl b/unidata/CreateGetType.pl
index ba17219..bfcbd66 100755
--- a/unidata/CreateGetType.pl
+++ b/unidata/CreateGetType.pl
@@ -251,9 +251,10 @@ sub create_c_file {
my $c_file =<<__;
/*========================================================================
// This file was automatically created from $unicode_proplist_file, version $proplist_version,
// and $unicode_mirroring_file, version $mirroring_version, by the perl script CreateGetType.pl.
//----------------------------------------------------------------------*/
#include "fribidi.h"
@@ -371,5 +372,7 @@ __
$c_file .= "gint nFriBidiMirroredChars = "
. scalar(@mirrors) . ";\n";
+ $c_file .="\n\n/* *INDENT-ON* */\n";
+
print $c_file;
}
@@ -251,9 +251,10 @@ sub create_c_file {
my $c_file =<<__;
/*========================================================================
-// This file was automatically created from $unicode_proplist_file, version $proplist_version,
-// and $unicode_mirroring_file, version $mirroring_version, by the perl script CreateGetType.pl.
-//----------------------------------------------------------------------*/
+ * This file was automatically created from $unicode_proplist_file, version $proplist_version,
+ * and $unicode_mirroring_file, version $mirroring_version, by the perl script CreateGetType.pl.
+ *----------------------------------------------------------------------*/
+/* *INDENT-OFF* */
#include "fribidi.h"